%define pver p15

# pool.ntp.org vendor zone which will be used in ntp.conf
# use fedora, as long as we don't have a mageia specific one
%define vendorzone fedora

Summary:        Synchronizes system time using the Network Time Protocol (NTP)
Name:           ntp
Version:        4.2.8%{pver}
Release:        %mkrel 1
License:        BSD-Style
Group:          System/Servers
URL:            http://www.ntp.org/
Source0:        http://www.eecis.udel.edu/~ntp/ntp_spool/ntp4/ntp-4.2/%{name}-%{version}.tar.gz
Source99:       http://www.eecis.udel.edu/~ntp/ntp_spool/ntp4/ntp-4.2/%{name}-%{version}.tar.gz.md5
Source1:        ntp.conf.v2
Source2:        ntp.keys
Source4:        ntpd.sysconfig
Source5:        https://github.com/mlichvar/ntpstat/archive/0.5/ntpstat-0.5.tar.gz
Source6:        ntp.step-tickers
Source7:        ntpdate.wrapper
Source8:        ntp.cryptopw
Source9:        ntpdate.sysconfig
Source10:       ntp.dhclient
Source12:       ntpd.service
Source13:       ntpdate.service
Source14:       ntp-wait.service
Source15:       sntp.service
Source16:       sntp.sysconfig
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  elfutils-devel
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libedit)
BuildRequires:  net-snmp-devel
BuildRequires:  bison
BuildRequires:  pps-tools-devel
# for html2man
BuildRequires:  perl(HTML::Parser)

%description
The Network Time Protocol (NTP) is used to synchronize a computer's time
with another reference time source. This package includes ntpd
(a daemon which continuously adjusts system time) and utilities used
to query and configure the ntpd daemon.

Perl scripts are in the ntp-perl package, ntpdate is in the ntpdate
package and sntp is in the sntp package. The documentation in HTML
format is in the ntp-doc package.


%package perl
Summary:    NTP utilities written in Perl
Group:      System/Servers
Requires:   %{name} = %{version}-%{release}
Obsoletes:  %{name} < 4.2.8p10
BuildArch:  noarch

%description perl
This package contains Perl scripts calc_tickadj, ntp-wait and ntptrace.

%package -n ntpdate
Summary:    Utility to set the date and time via NTP
Group:      System/Servers
Obsoletes:  ntp-client

%description -n ntpdate
ntpdate is a program for retrieving the date and time from
NTP servers.

%package -n sntp
Summary:    Standard Simple Network Time Protocol program
Group:      System/Servers

%description -n sntp
sntp can be used as a SNTP client to query a NTP or SNTP server and either
display the time or set the local system's time (given suitable privilege).
It can be run as an interactive command or in a cron job.

%package doc
Summary:    Complete HTML documentation for ntp
Group:      System/Servers
BuildArch:	noarch

%description doc
This is the original, complete, documentation for NTP, in HTML format.
Manpages documentation comes with the binary package(s).

The Network Time Protocol (NTP) is used to synchronize a computer's time
with another reference time source.  The ntp package contains utilities
and daemons which will synchronize your computer's time to Coordinated
Universal Time (UTC) via the NTP protocol and NTP servers.  Ntp includes
ntpdate (a program for retrieving the date and time from remote machines
via a network) and ntpd (a daemon which continuously adjusts system time).

%prep
%setup -q -a5

# fix format and encoding of packaged documentation
sed -i 's|\r||g' html/scripts/{footer.txt,style.css}
for f in COPYRIGHT; do
	iconv -f iso8859-1 -t utf8 -o ${f}{_,} && touch -r ${f}{,_} && mv -f ${f}{_,}
done

%build
%serverbuild

sed -i 's|$CFLAGS -Wstrict-overflow|$CFLAGS|' configure sntp/configure
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fno-strict-overflow"
%configure \
    --sysconfdir=%{_sysconfdir}/ntp/crypto \
	--with-locfile=redhat \
	--without-ntpsnmpd \
	--enable-all-clocks \
	--enable-parse-clocks \
	--enable-ntp-signd=%{_localstatedir}/run/ntp_signd \
	--disable-local-libopts

# fix default paths that are not configurable

sed -i 's|/var/db/ntp-kod|%{_localstatedir}/lib/sntp/kod|' \
    sntp/sntp{-opts.c,.1*}
sed -i 's|/etc/ntp/drift|%{_localstatedir}/lib/ntp/drift|' \
	scripts/calc_tickadj/calc_tickadj{,.m*.in}
echo '#define KEYFILE "%{_sysconfdir}/ntp/keys"' >> ntpdate/ntpdate.h
echo '#define NTP_VAR "%{_localstatedir}/log/ntpstats/"' >> config.h

%make_build
%make_build -C ntpstat-0.5

# generate manpages from HTML docs
sed -e 's|@PATH_PERL@|%{_bindir}/perl|' -e 's|@[^@]*_MS@|8|g' \
	< scripts/deprecated/html2man.in \
	> scripts/deprecated/html2man
pushd html
perl ../scripts/deprecated/html2man
# remove adjacent blank lines
sed -i 's/^[\t\ ]*$//;/./,/^$/!d' man/man*/*.[58]
popd 

%install
%make_install bindir=%{_sbindir}
%makeinstall -C ntpstat-0.5

# install missing man pages (generated from HTML)
cp -r html/man/man8/{ntpdate,ntptime,tickadj}* %{buildroot}%{_mandir}/man8

# package only selected documentation
rm -rf %{buildroot}%{_docdir}
install -d -m 755 -p %{buildroot}%{_docdir}/ntp
cp -p COPYRIGHT ChangeLog NEWS %{buildroot}%{_docdir}/ntp

# prepare html documentation
find html | grep -E '\.(html|css|txt|jpg|gif)$' | grep -v '/build/\|sntp' | \
	cpio -pmd %{buildroot}%{_docdir}/ntp
find %{buildroot}%{_docdir}/ntp -type f | xargs chmod 644
find %{buildroot}%{_docdir}/ntp -type d | xargs chmod 755

install -d -m 755 %{buildroot}%{_sysconfdir}
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/ntp.conf
install -d -m 755 %{buildroot}%{_sysconfdir}/ntp
install -p -m 600 %{SOURCE2} %{buildroot}%{_sysconfdir}/ntp/keys
install -p -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/ntp/step-tickers
install -d -m 750 %{buildroot}%{_sysconfdir}/ntp/crypto
install -p -m 600 %{SOURCE8} %{buildroot}%{_sysconfdir}/ntp/crypto/pw

install -d -m 755 %{buildroot}%{_libexecdir}
install -p -m 755 %{SOURCE7} %{buildroot}%{_libexecdir}/ntpdate-wrapper

install -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE4}  %{buildroot}%{_sysconfdir}/sysconfig/ntpd
install -m 644 %{SOURCE9}  %{buildroot}%{_sysconfdir}/sysconfig/ntpdate
install -m 644 %{SOURCE16} %{buildroot}%{_sysconfdir}/sysconfig/sntp

sed -i \
    -e 's|VENDORZONE|%{vendorzone}|' \
	-e 's|ETCNTP|%{_sysconfdir}/ntp|' \
	-e 's|VARNTP|%{_localstatedir}/lib/ntp|' \
	%{buildroot}%{_sysconfdir}/ntp.conf
sed -i \
    -e 's|VENDORZONE|%{vendorzone}|'\
    %{buildroot}%{_sysconfdir}/ntp/step-tickers
sed -i \
    -e 's|VENDORZONE|%{vendorzone}|' \
	%{buildroot}%{_sysconfdir}/sysconfig/sntp

install -d -m 755 %{buildroot}%{_sysconfdir}/dhcp/dhclient.d
install -p -m 755 %{SOURCE10} %{buildroot}%{_sysconfdir}/dhcp/dhclient.d/ntp.sh

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE12} %{buildroot}%{_unitdir}/ntpd.service
install -m 644 %{SOURCE13} %{buildroot}%{_unitdir}/ntpdate.service
install -m 644 %{SOURCE14} %{buildroot}%{_unitdir}/ntp-wait.service
install -m 644 %{SOURCE15} %{buildroot}%{_unitdir}/sntp.service

install -d -m 755 %{buildroot}%{_prefix}/lib/systemd/ntp-units.d
echo 'ntpd.service' > %{buildroot}%{_prefix}/lib/systemd/ntp-units.d/60-ntpd.list

install -d -m 755 %{buildroot}%{_localstatedir}/lib/ntp
install -d -m 755 %{buildroot}%{_localstatedir}/lib/sntp
install -d -m 755 %{buildroot}%{_localstatedir}/log/ntpstats
touch %{buildroot}%{_localstatedir}/lib/ntp/drift
touch %{buildroot}%{_localstatedir}/lib/sntp/kod

%pre
%_pre_useradd ntp %{_sysconfdir}/ntp /bin/false

%post
%_post_service ntpd
/bin/touch %{_sysconfdir}/ntp/step-tickers

%preun
%_preun_service ntpd

%postun
%_postun_userdel ntp

%files
%doc COPYRIGHT ChangeLog NEWS
%config(noreplace) %{_sysconfdir}/sysconfig/ntpd
%config(noreplace) %{_sysconfdir}/ntp.conf
%dir %{_sysconfdir}/ntp
%config(noreplace) %{_sysconfdir}/ntp/keys
%dir %attr(-,root,ntp) %{_sysconfdir}/ntp/crypto
%config(noreplace) %{_sysconfdir}/ntp/crypto/pw
%dir %{_sysconfdir}/dhcp/dhclient.d
%{_sysconfdir}/dhcp/dhclient.d/ntp.sh
%dir %attr(-,ntp,ntp) %{_localstatedir}/lib/ntp
%ghost %attr(-,ntp,ntp) %{_localstatedir}/lib/ntp/drift
%dir %attr(-,ntp,ntp) %{_localstatedir}/log/ntpstats
%{_sbindir}/ntp-keygen
%{_sbindir}/ntpd
%{_sbindir}/ntpdc
%{_sbindir}/ntpq
%{_sbindir}/ntptime
%{_sbindir}/tickadj
%{_bindir}/ntpstat
%{_mandir}/man1/ntpstat.1*
%{_mandir}/man5/ntp.conf.5*
%{_mandir}/man5/ntp.keys.5*
%{_mandir}/man8/ntp-keygen.8*
%{_mandir}/man8/ntpd.8*
%{_mandir}/man8/ntpdc.8*
%{_mandir}/man8/ntpq.8*
%{_mandir}/man8/ntptime.8*
%{_mandir}/man8/tickadj.8*
%{_prefix}/lib/systemd/ntp-units.d/*.list
%{_unitdir}/ntpd.service

%files perl
%{_sbindir}/calc_tickadj
%{_sbindir}/ntp-wait
%{_sbindir}/ntptrace
%{_mandir}/man8/calc_tickadj.8*
%{_mandir}/man8/ntp-wait.8*
%{_mandir}/man8/ntptrace.8*
%{_unitdir}/ntp-wait.service
%{_datadir}/ntp

%files -n ntpdate
%doc COPYRIGHT README
%{_sbindir}/ntpdate
%{_libexecdir}/ntpdate-wrapper
%{_mandir}/man8/ntpdate.8*
%{_unitdir}/ntpdate.service
%config(noreplace) %{_sysconfdir}/sysconfig/ntpdate
%config(noreplace) %{_sysconfdir}/ntp/step-tickers

%files -n sntp
%doc sntp/COPYRIGHT
%{_sbindir}/sntp
%{_mandir}/man8/sntp.8*
%dir %{_localstatedir}/lib/sntp
%ghost %{_localstatedir}/lib/sntp/kod
%{_unitdir}/sntp.service
%config(noreplace) %{_sysconfdir}/sysconfig/sntp

%files doc
%{_docdir}/ntp/html


%changelog
* Wed Jun 24 2020 ns80 <ns80> 4.2.8p15-1.mga8
+ Revision: 1599052
- new version 4.2.8p15 for a security issue (mga#26851)

* Thu May 07 2020 ns80 <ns80> 4.2.8p14-1.mga8
+ Revision: 1581412
- new version 4.2.8p14 for CVE-2020-11868 and two other security issues (mga#26597)

* Sat Feb 15 2020 umeabot <umeabot> 4.2.8p13-2.mga8
+ Revision: 1524267
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Mar 29 2019 ns80 <ns80> 4.2.8p13-1.mga7
+ Revision: 1381109
- update to 4.2.8p13 for CVE-2019-8936 (mga#24585)
- update ntpstat to 0.5

* Sat Dec 29 2018 luigiwalser <luigiwalser> 4.2.8p12-2.mga7
+ Revision: 1346028
- rebuild for net-snmp

* Wed Sep 05 2018 ns80 <ns80> 4.2.8p12-1.mga7
+ Revision: 1257274
- new version 4.2.8p12 for CVE-2018-12327 (mga#23505)

* Sun Apr 01 2018 zezinho <zezinho> 4.2.8p11-1.mga7
+ Revision: 1214072
- new version 4.2.8p11 fixes security bug

* Sat Nov 18 2017 zezinho <zezinho> 4.2.8p10-5.mga7
+ Revision: 1177681
- rebuild against pps fixing MGA#15790

* Tue Aug 08 2017 guillomovitch <guillomovitch> 4.2.8p10-4.mga7
+ Revision: 1139074
+ rebuild (emptylog)

* Tue Aug 08 2017 guillomovitch <guillomovitch> 4.2.8p10-3.mga7
+ Revision: 1139073
- drop dependency on ntp-client
- fix zone substitution in config files

* Tue Aug 08 2017 guillomovitch <guillomovitch> 4.2.8p10-2.mga7
+ Revision: 1139023
- new version 4.2.8p10
  sync packaging with fedora

* Wed Mar 29 2017 luigiwalser <luigiwalser> 4.2.6p5-33.mga6
+ Revision: 1095163
- add patches from fedora to fix security issues:
  - fix crash with invalid unpeer command (CVE-2017-6463)
  - fix buffer overflow in datum refclock driver (CVE-2017-6462)
  - fix potential buffer overflow in mx4200 refclock driver (CVE-2017-6451)
  - fix potential buffer overflows in formatting of ntpq responses
    (CVE-2017-6458)
  - fix potential crash with invalid server command (CVE-2017-6464)
- update patches from fedora to fix bugs:
  - fix CVE-2016-7429 patch to work correctly on multicast client
  - fix typos in ntpd man page (#1434755)

* Fri Nov 25 2016 luigiwalser <luigiwalser> 4.2.6p5-32.mga6
+ Revision: 1070155
- add patches from fedora to fix security issues:
  - don't limit rate of packets from sources (CVE-2016-7426)
  - don't change interface from received packets (CVE-2016-7429)
  - require authentication for trap commands (CVE-2016-9310)
  - fix crash when reporting peer event to trappers (CVE-2016-9311)

* Fri Jun 03 2016 luigiwalser <luigiwalser> 4.2.6p5-31.mga6
+ Revision: 1020184
- add patches from fedora to fix more security issues:
  - CVE-2015-8139
  - CVE-2016-4954
  - CVE-2016-4955
  - CVE-2016-4956

* Thu May 12 2016 luigiwalser <luigiwalser> 4.2.6p5-30.mga6
+ Revision: 1014159
- add patches from fedora to fix more bugs and security issues:
- update reference timestamp in orphan mode
- allow sources specified by IPv6 link-local address
- don't allow spoofed packet to enable symmetric interleaved mode
  (CVE-2016-1548)
- don't crash on duplicate address in unconfig command (CVE-2016-2516)
- check mode of new source in config command (CVE-2016-2518)
- make MAC check resilient against timing attack (CVE-2016-1550)

* Mon Jan 25 2016 luigiwalser <luigiwalser> 4.2.6p5-28.mga6
+ Revision: 927118
- rename CVE-2015-5196 to CVE-2015-7703
- fix CVE-2015-7692 patch name
- add patches from fedora to fix several bugs and security issues:
- report clock state changes related to leap seconds
- allow -4/-6 on restrict lines with mask
- explain synchronised state in ntpstat man page
- don't accept server/peer packets with zero origin timestamp (CVE-2015-8138)
- fix crash with reslist command (CVE-2015-7977, CVE-2015-7978)
- fix infinite loop in ntpq/ntpdc (CVE-2015-8158)
- check key ID in packets authenticated with symmetric key (CVE-2015-7974)
- don't allow spoofed packets to demobilize associations using symmetric key
  (CVE-2015-7979)

* Wed Oct 28 2015 luigiwalser <luigiwalser> 4.2.6p5-27.mga6
+ Revision: 896075
- add patches from ubuntu to fix CVE-2015-785[035]

* Thu Oct 22 2015 luigiwalser <luigiwalser> 4.2.6p5-26.mga6
+ Revision: 894253
- sync with fedora to fix October 2015 security issues:
  - check origin timestamp before accepting KoD RATE packet (CVE-2015-7704)
  - allow only one step larger than panic threshold with -g (CVE-2015-5300)
  - fix memory leak with autokey (CVE-2015-7701)
  - don't crash with crafted autokey packet (CVE-2015-7691, CVE-2015-7692,
    CVE-2015-7702)
  - don't crash in ntpq with crafted packet (CVE-2015-7852)
  - don't mobilize passive association with crypto NAK (CVE-2015-7871)

* Wed Sep 02 2015 luigiwalser <luigiwalser> 4.2.6p5-25.mga6
+ Revision: 872222
- add patches from fedora to fix CVE-2015-5146, CVE-2015-519[4-6], CVE-2015-5219

* Wed Apr 08 2015 oden <oden> 4.2.6p5-24.mga5
+ Revision: 819877
- P30: security fix for CVE-2015-1798
- P31: security fix for CVE-2015-1799

* Sat Feb 28 2015 alien <alien> 4.2.6p5-23.mga5
+ Revision: 817214
- New configurations are advised to use Orphan mode instead of local clocks

* Tue Feb 10 2015 luigiwalser <luigiwalser> 4.2.6p5-22.mga5
+ Revision: 814542
- do not restrict ntpq from localhost

* Fri Feb 06 2015 luigiwalser <luigiwalser> 4.2.6p5-21.mga5
+ Revision: 813679
- add patches from fedora to fix CVE-2014-9297 and CVE-2014-9298

* Sat Dec 20 2014 luigiwalser <luigiwalser> 4.2.6p5-20.mga5
+ Revision: 804330
- link to openssl to fix build with CVE-2014-9294 patch
- add patches from fedora to fix CVE-2014-929[3-6]

* Wed Oct 15 2014 umeabot <umeabot> 4.2.6p5-17.mga5
+ Revision: 748582
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.2.6p5-16.mga5
+ Revision: 682949
- Mageia 5 Mass Rebuild

* Thu Jan 23 2014 luigiwalser <luigiwalser> 4.2.6p5-15.mga4
+ Revision: 567555
- restrict some remote query types by default to mitigate CVE-2013-5211 (mga#12326)

* Sat Nov 23 2013 colin <colin> 4.2.6p5-14.mga4
+ Revision: 552447
- Remove legacy directive from service unit

* Sat Oct 19 2013 umeabot <umeabot> 4.2.6p5-13.mga4
+ Revision: 522749
- Mageia 4 Mass Rebuild

* Tue Mar 26 2013 tv <tv> 4.2.6p5-12.mga3
+ Revision: 405373
- make doc subpackage noarch

* Tue Feb 26 2013 colin <colin> 4.2.6p5-11.mga3
+ Revision: 400393
- Revert (most of) r397878. ntpd -q does not behave like ntpdate at all.

* Mon Feb 11 2013 colin <colin> 4.2.6p5-10.mga3
+ Revision: 397879
- Tidy unit paths
- Drop the ntpdate service (unneeded due to -g option to ntpd)

* Sat Jan 12 2013 umeabot <umeabot> 4.2.6p5-9.mga3
+ Revision: 361075
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 cjw <cjw> 4.2.6p5-8.mga3
+ Revision: 339648
- patch301: fix build with automake 1.13

* Thu Aug 09 2012 tv <tv> 4.2.6p5-7.mga3
+ Revision: 280281
- drop sysv service

* Fri Jul 20 2012 colin <colin> 4.2.6p5-6.mga3
+ Revision: 272730
- Fix systemd units and add ntp service list definition for high level auto-activation.

* Thu May 03 2012 colin <colin> 4.2.6p5-5.mga2
+ Revision: 234622
- Bind to the generic systemd-timedated-ntp target (future proofing)
- Keep ntpd in the root cpu control group to allow it to set it's schedulling priority (rhbz#810801)

* Sat Apr 28 2012 tmb <tmb> 4.2.6p5-4.mga2
+ Revision: 233824
- Require rpm-helper >= 0.24.8-1 for systemd support

* Wed Mar 28 2012 luigiwalser <luigiwalser> 4.2.6p5-3.mga2
+ Revision: 227388
- better fix for mga #4944 suggested by Colin Guthrie

* Sun Mar 25 2012 luigiwalser <luigiwalser> 4.2.6p5-2.mga2
+ Revision: 226420
- call _post_service for ntpdate (mga #4944)
- switch service type to forking (from fedora)

* Sun Feb 12 2012 luigiwalser <luigiwalser> 4.2.6p5-1.mga2
+ Revision: 207614
- 4.2.6p5 (updated patches from fedora by way of mdv)
- enable PrivateTmp in ntpd service (rh #782520)

* Fri Sep 09 2011 guillomovitch <guillomovitch> 4.2.6p3-7.mga2
+ Revision: 141790
- ensure variable in sysconfig/ntp are consistant for both sysinit and systemd

* Fri Sep 09 2011 guillomovitch <guillomovitch> 4.2.6p3-6.mga2
+ Revision: 141730
- ship ntpdate wrapper configuration file too

* Thu Sep 08 2011 guillomovitch <guillomovitch> 4.2.6p3-5.mga2
+ Revision: 141412
- don't forget to ship the ntpdate wrapper for systemd

* Tue Sep 06 2011 guillomovitch <guillomovitch> 4.2.6p3-4.mga2
+ Revision: 139781
- add missing LSB header
- spec cleanup
- drop apparmor config files
- add systemd service files
- rebuild for latest net-snmp

* Tue Feb 08 2011 ennael <ennael> 4.2.6p3-2.mga1
+ Revision: 49055
- imported package ntp

